use super::*;

pub enum DirectoryRecordMember {
    Directory{name: String},
    File{name: String},
}

impl DirectoryRecordMember {
    pub fn get_name(&self) -> &String {
        match self {
            DirectoryRecordMember::Directory{name} => name,
            DirectoryRecordMember::File{name}      => name,
        }
    }
}

pub fn collect_directory_record_member(files: &Vec<File>, dirs: &Vec<Directory>) -> Vec<DirectoryRecordMember> {
    let mut collection = Vec::new();

    collection.push(DirectoryRecordMember::Directory{name: "\x00".to_owned()});
    collection.push(DirectoryRecordMember::Directory{name: "\x01".to_owned()});
    for file in files {
        if !file.properties.is_hidden {
            if let Some(name) = file.name.as_string() {
                collection.push(DirectoryRecordMember::File{name});
            }
        }
    }

    for dir in dirs {
        if !dir.properties.is_hidden {
            if let Some(name) = dir.name.as_string() {
                collection.push(DirectoryRecordMember::Directory{name});
            }
        }
    }

    collection.sort_by(|a, b| {a.get_name().cmp(b.get_name())});
    collection
}
